@@ -10,12 +10,8 @@
 #ifndef BUTTON_H
 #define BUTTON_H
 
-#include <qobject.h>
-
 #include "blinkengame.h"
 
-class KAction;
-
 class button
 {
 	public:
